@@ -1,6 +1,6 @@
 """	Command line entry point and metadata """
 
-__version__ = 1.0
+__version__ = 1.1
 
 from parser		import roll
 from pyparsing	import ParseException
@@ -13,20 +13,19 @@ def command ():
 	parser.add_argument('--version', action='version',
 		version='bones v%s' % __version__)
 	
-	parser.add_argument('--profile', action='store_true',
-		help='run using the cProfile profiler')
-		
+	parser.add_argument('-v', '--verbose', action='store_true',
+		help='log the evaluation')
+	
 	parser.add_argument('expression', type=str,
 		help='the expression to roll')
-	
+		
 	args = parser.parse_args()
 	
 	try:
-		if args.profile:
-			from cProfile import runctx
-			runctx('print roll(args.expression)', globals(), locals())
-		else:
-			print roll(args.expression)
+		result = roll(**vars(args))
+		if args.verbose:
+			print "Result:",
+		print result
 	except ParseException as e:
 		import sys
 		print >> sys.stderr, "Parse failed:", e
